@@ -34,6 +34,10 @@ pub struct Proxy {
 
 // TODO: add `#[track_caller]` after https://github.com/rust-lang/rust/issues/78840.
 impl Proxy {
+    pub fn addr(self) -> Addr {
+        self.context.addr()
+    }
+
     pub async fn send<M: Message>(&self, message: M) {
         tls::scope(self.meta.clone(), trace_id::generate(), async {
             let res = self.context.send(message).await;
